gchecky.gxml.Integer

Package gchecky :: Module gxml :: Class Integer |
[hide private]
[frames] | no frames]

# Class Integer

source code

    object --+
             |
         Field --+
                 |
              Long --+
                     |
                    Integer

Instance Methods | [hide private]
Inherited from `Long`: `data2str`, `str2data` Inherited from `Field`: `__init__`, `__repr__`, `create_node_for_path`, `get_any_node_for_path`, `get_initial_value`, `get_nodes_for_path`, `get_one_node_for_path`, `load`, `save`, `validate` Inherited from `Field` (private): `_traits` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `Field`: `deconstruct_path`, `reconstruct_path`

Class Variables | [hide private]
Inherited from `Long`: `default`

Instance Variables | [hide private]
Inherited from `Field`: `empty`, `path`, `required`, `save_node_and_xml`, `values`

Properties | [hide private]
Inherited from `object`: `__class__`